@@ -166,6 +166,7 @@ OC.L10N.register(
     "Add to group" : "添加到群组",
     "Search {types}" : "搜索 {types}",
     "Search for people to add" : "搜索要添加的人",
+    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "请注意，您只能将可写通讯录中的联系人添加到联系人组。无法添加只读通讯录（如系统通讯录）中的联系人。",
     "No results" : "无结果",
     "Add {type}" : "添加  {type}",
     "New team name" : "新团队名称",
@@ -187,6 +188,8 @@ OC.L10N.register(
     "Promote as sole owner" : "提升为唯一所有人",
     "Promote to {level}" : "提升为 {level}",
     "Demote to {level}" : "降级为 {level}",
+    "Are you sure you want to leave this team? This action cannot be undone." : "是否确定要离开此团队？此操作无法撤销。",
+    "Leave team failed." : "离开团队失败。",
     "Could not delete the member {displayName}" : "无法删除成员 {displayName}",
     "Could not change the member level to {level}" : "无法更改成员级别到 {level}",
     "Could not accept membership request" : "无法接受成员身份请求",
@@ -206,13 +209,14 @@ OC.L10N.register(
     "Unable to create the contact." : "未能成功创建联系人。",
     "Contact not found" : "未找到联系人",
     "Group {group} not found" : "未找到群组 {group} ",
+    "Add member" : "添加成员",
     "New contact" : "新建联系人",
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 位联系人已添加到 {name}"],
-    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["正在添加 {success} 位联系人到 {name}"],
+    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["正在将 {success} 位联系人添加到 {name}"],
     "_{count} error_::_{count} errors_" : ["{count} 个错误"],
     "Close" : "关闭",
-    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在导入 %n 个联系人到 {addressbook}"],
-    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["已将 %n 个联系人导入到 {addressbook}"],
+    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在将 %n 位联系人导入 {addressbook}"],
+    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["已将 %n 位联系人导入 {addressbook}"],
     "No data for this contact" : "此联系人无数据",
     "No data for this contact on their profile" : "此联系人的个人资料中没有相关数据",
     "Import" : "导入",
