@@ -166,6 +166,7 @@ OC.L10N.register(
     "Add to group" : "新增至群組",
     "Search {types}" : "搜尋 {types}",
     "Search for people to add" : "搜索要添加的人",
+    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "請注意，您只能將可寫通訊錄中的聯絡人添加到聯絡人群組。來自唯讀通訊錄的聯絡人，例如系統通訊錄，無法添加。",
     "No results" : "沒有結果",
     "Add {type}" : "新增 {type}",
     "New team name" : "新團隊名字",
@@ -187,6 +188,8 @@ OC.L10N.register(
     "Promote as sole owner" : "晉升作為唯一所有者",
     "Promote to {level}" : "晉升到 {level}",
     "Demote to {level}" : "降級到 {level}",
+    "Are you sure you want to leave this team? This action cannot be undone." : "您確定要離開此團隊嗎？此操作無法復原。",
+    "Leave team failed." : "離開團隊失敗。",
     "Could not delete the member {displayName}" : "不能刪除成員 {displayName}",
     "Could not change the member level to {level}" : "無法將成員級別更改為 {level}",
     "Could not accept membership request" : "無法接受成為成員的申請",
@@ -206,6 +209,7 @@ OC.L10N.register(
     "Unable to create the contact." : "無法建立聯絡人",
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
+    "Add member" : "添加成員",
     "New contact" : "新聯絡人",
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
     "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
@@ -322,11 +326,6 @@ OC.L10N.register(
     "An error has occurred in team(s). Check the console for more details." : "團隊中出現錯誤。請檢查主控台以取得更多詳細資訊。",
     "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
-    "Unable to delete contact" : "無法刪除聯絡人",
-    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "會員資格必須由版主確認/接受（需要開放）",
-    "Manager" : "經理",
-    "Members" : "成員",
-    "Manage members" : "管理成員",
-    "Show team details" : "顯示團隊詳細資訊"
+    "Unable to delete contact" : "無法刪除聯絡人"
 },
 "nplurals=1; plural=0;");
