@@ -166,6 +166,7 @@ OC.L10N.register(
     "Add to group" : "新增至群組",
     "Search {types}" : "搜尋 {types}",
     "Search for people to add" : "搜尋要新增的人",
+    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "請注意，您只能將可寫通訊錄中的聯絡人新增至聯絡人群組。來自唯讀通訊錄（例如系統通訊錄）的聯絡人則無法新增。",
     "No results" : "沒有結果",
     "Add {type}" : "新增 {type}",
     "New team name" : "新團隊名稱",
@@ -187,6 +188,8 @@ OC.L10N.register(
     "Promote as sole owner" : "將其權限升級為唯一擁有者",
     "Promote to {level}" : "將其權限升級為 {level}",
     "Demote to {level}" : "將其權限降級為 {level}",
+    "Are you sure you want to leave this team? This action cannot be undone." : "您確定您想要離開此團隊嗎？此動作無法還原。",
+    "Leave team failed." : "離開團隊失敗。",
     "Could not delete the member {displayName}" : "無法刪除成員 {displayName}",
     "Could not change the member level to {level}" : "無法變更成員等級至 {level}",
     "Could not accept membership request" : "無法接受成員請求",
@@ -206,6 +209,7 @@ OC.L10N.register(
     "Unable to create the contact." : "無法建立聯絡人",
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
+    "Add member" : "新增成員",
     "New contact" : "新聯絡人",
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
     "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
